@@ -7,6 +7,7 @@ require 'rspec/mocks/method_double'
 require 'rspec/mocks/methods'
 require 'rspec/mocks/argument_matchers'
 require 'rspec/mocks/proxy'
+require 'rspec/mocks/test_double'
 require 'rspec/mocks/mock'
 require 'rspec/mocks/argument_expectation'
 require 'rspec/mocks/message_expectation'
@@ -15,3 +16,4 @@ require 'rspec/mocks/errors'
 require 'rspec/mocks/error_generator'
 require 'rspec/mocks/space'
 require 'rspec/mocks/serialization'
+require 'rspec/mocks/any_instance'
